@@ -1,5 +1,5 @@
 package Getopt::EX::Module;
-use version; our $VERSION = version->declare("2.1.5");
+use version; our $VERSION = version->declare("2.1.6");
 
 use v5.14;
 use warnings;
@@ -115,7 +115,7 @@ sub readrc {
 sub module {
     my $obj = shift;
     @_  ? $obj->{Module} = shift
-	: $obj->{Module};
+	: $obj->{Module} // '';
 }
 
 sub title {
